==> trims_overhaul-DP_RP-v3.0.2.zip: README.md <==
![](https://cdn.modrinth.com/data/cached_images/edc7b63bd1a8673cc36f1a3902fee1a3b1faa228.png)

> #### Lightweight datapack that gives every trim unique powers, obtainable through one-time objectives.

### Join the [Discord](https://discord.gg/3Pj7GszXPM) for any help or issues - Check out the [Wiki](https://github.com/ActuallyBlue/Trims_Overhaul/wiki) for more information whenever

#### Supports translations in: English, Español, Deutsch, Polski, Français, Português, Русский, 한국어, 日本語, and 简体中文 ⁽ᴺᵒᵗ ᴾᵉʳᶠᵉᶜᵗ⁾


- If you're interested in staying up to date, or enjoy the project, then please consider following.
- Feel free to use this datapack however you like, just with credit when possible.

<details><summary> Installation Guides </summary>

## ------- Datapack & Resource Pack-------------------------------
 - Download the second file in the versions tab. (Should look like `trims_overhaul-DP_RP-vX.X.X.zip`)

<br>

 - For the data pack; Open your world folder (`.minecraft/saves/world`)
   - Drop the zip into the `datapacks` folder as-is
   - Then restart the server or world — /reload won't work
    - When updating; don't disable the datapack, otherwise some progress will be lost.

<br>
  
 - For the resource pack; In Minecraft, go to Options > Resource Packs
   - Then drag the new zip file into your Minecraft
   - And click on the arrow on the new pack to enable it.

<br>

## -- Mod (Bundle for mod loaders) ----
 - May vary depending on your loader, but simply
  download the first file in the versions tab,
  and then drag it into your mods folder, usually
  located at `.minecraft/mods`. Possibly
  accessible through any "mods" button ingame
 - The previous `.zip` can be renamed to `.jar`, which'll instead make it work as a mod.

</details>

==> trims_overhaul-DP_RP-v3.1.0.zip: README.md <==
![](https://cdn.modrinth.com/data/cached_images/edc7b63bd1a8673cc36f1a3902fee1a3b1faa228.png)

> #### Lightweight datapack that gives every trim unique powers, obtainable through one-time objectives.

### Join the [Discord](https://discord.gg/3Pj7GszXPM) for any help or issues - Check out the [Wiki](https://github.com/ActuallyBlue/Trims_Overhaul/wiki) for more information whenever

#### Supports translations in: English, Español, Français, Deutsch, Polski, Italiano, Português, Türkçe, Русский, 한국어, 日本語, and 简体中文 ⁽ᴺᵒᵗ ᴾᵉʳᶠᵉᶜᵗ⁾


- If you're interested in staying up to date, or enjoy the project, then please consider following.
- Feel free to use this datapack however you like, just with credit when possible.

<details><summary> Installation Guides </summary>

## ------- Datapack & Resource Pack-------------------------------
 - Download the second file in the versions tab. (Should look like `trims_overhaul-DP_RP-vX.X.X.zip`)

<br>

 - For the data pack; Open your world folder (`.minecraft/saves/world`)
   - Drop the zip into the `datapacks` folder as-is
   - Then restart the server or world — `/reload` won't work
     - When updating, don't disable the datapack or else some progress will be lost. The server should instead be closed, delete and replace the datapack, and then re-open it.

<br>

 - For the resource pack; In Minecraft, go to Options > Resource Packs
   - Then drag the new zip file into your Minecraft
   - And click on the arrow on the new pack to enable it.

<br>

## -- Mod (Bundle for mod loaders) ----
 - May vary depending on your loader, but simply
  download the first file in the versions tab,
  and then drag it into your mods folder, usually
  located at `.minecraft/mods`. Possibly
  accessible through any "mods" button ingame
 - The previous `.zip` can be renamed to `.jar`, which'll instead make it work as a mod.

</details>
